==> jsonstreamreader-1.1.1.tar.gz: lib/state/reader/abstractstatereader.dart <==
import 'dart:collection';
import 'dart:convert';

import 'token/jsontokenstate.dart';

///Represent the last known state of Reader/StreamReader
abstract class AbstractStateReader {
  JsonTokenState jsontokenstate;
  String _file;
  //streamer
  int _start;
  int _end;
  int _delay;
  int _combine;
  int _chunksize = 100;
  int _group;
  //Reader parse data
  List<MapEntry<String, dynamic>> _parse;
  //
  AbstractStateReader(
      JsonTokenState jsontokenstate,
      int group,
      String file,
      int start,
      int end,
      int delay,
      int combine,
      int chunksize,
      List<MapEntry<String, dynamic>> parse) {
    this.jsontokenstate = jsontokenstate;
    this._group = group;
    this._file = file;
    this._start = start;
    this._end = end;
    this._delay = delay;
    this._combine = combine;
    this._chunksize = chunksize;
    this._parse = parse;
  }
  //Convert state to string
  String toString() {
    Map<String, dynamic> state = new Map<String, dynamic>();
    state['jsontokenstate'] = this.jsontokenstate.toMap();
    state['group'] = this._group;
    state['file'] = this._file;
    state['start'] = this._start;
    state['end'] = this._end;
    state['delay'] = this._delay;
    state['combine'] = this._combine;
    state['chunksize'] = this._chunksize;
    state['parse'] = new List<Map<String, dynamic>>();
    this._parse.forEach((MapEntry<String, dynamic> v) {
      Map<String, dynamic> map = new Map<String, dynamic>();
      map[v.key] = v.value;
      state['parse'].add(map);
    });
    return jsonEncode(state);
  }

  //Convert map to state
  AbstractStateReader.fromMap(Map<String, dynamic> content) {
    this.jsontokenstate =
        new JsonTokenState.empty().fromMap(content['jsontokenstate']);
    this._group = content['group'];
    this._file = content['file'];
    this._start = content['start'];
    this._end = content['end'];
    this._delay = content['delay'];
    this._combine = content['combine'];
    this._chunksize = content['chunksize'];
    content['parse'].forEach((dynamic value) {
      String key = value.keys.first.toString();
      if (value.values.first.runtimeType.toString().contains("Map")) {
        HashMap<String, dynamic> data = new HashMap<String, dynamic>();
        value.values.first.forEach((dynamic vkey, dynamic vv) {
          data[vkey.toString()] = vv;
        });
        parse.add(new MapEntry(key, data));
      } else {
        this._parse.add(new MapEntry(
            key,
            value.values.runtimeType.toString().contains('int')
                ? value.values.first.toString()
                : value.values.first));
      }
    });
  }
  //Convert string to state
  AbstractStateReader.fromString(String content) {
    Map<String, dynamic> state = jsonDecode(content);
    this.jsontokenstate =
        new JsonTokenState.empty().fromMap(state['jsontokenstate']);
    this._group = state['group'];
    this._file = state['file'];
    this._start = state['start'];
    this._end = state['end'];
    this._delay = state['delay'];
    this._combine = state['combine'];
    this._chunksize = state['chunksize'];
    this._parse = new List<MapEntry<String, dynamic>>();
    state['parse'].forEach((dynamic value) {
      String key = value.keys.first.toString();
      if (value.values.first.runtimeType.toString().contains("Map")) {
        HashMap<String, dynamic> data = new HashMap<String, dynamic>();
        value.values.first.forEach((dynamic vkey, dynamic vv) {
          data[vkey.toString()] = vv;
        });
        parse.add(new MapEntry(key, data));
      } else {
        this._parse.add(new MapEntry(
            key,
            value.values.runtimeType.toString().contains('int')
                ? value.values.first.toString()
                : value.values.first));
      }
    });
  }

  int get group {
    return this._group;
  }

  String get file {
    return this._file;
  }

  int get start {
    return this._start;
  }

  int get end {
    return this._end;
  }

  int get delay {
    return this._delay;
  }

  int get combine {
    return this._combine;
  }

  int get chunksize {
    return this._chunksize;
  }

  bool get isRemote {
    return this._file.startsWith('{');
  }

  List<MapEntry<String, dynamic>> get parse {
    return this._parse;
  }
}

==> jsonstreamreader-1.1.8.tar.gz: lib/state/reader/abstractstatereader.dart <==
import 'dart:collection';
import 'dart:convert';

import 'token/jsontokenstate.dart';

///Represent the last known state of Reader/StreamReader
abstract class AbstractStateReader {
  JsonTokenState jsontokenstate;
  String _file;
  int _start;
  int _end;
  int _delay;
  int _combine;
  int _chunksize = 100;
  int _group;

  ///Reader parse data
  List<MapEntry<String, dynamic>> _parse;
  AbstractStateReader(
      JsonTokenState jsontokenstate,
      int group,
      String file,
      int start,
      int end,
      int delay,
      int combine,
      int chunksize,
      List<MapEntry<String, dynamic>> parse) {
    this.jsontokenstate = jsontokenstate;
    this._group = group;
    this._file = file;
    this._start = start;
    this._end = end;
    this._delay = delay;
    this._combine = combine;
    this._chunksize = chunksize;
    this._parse = parse;
  }

  ///Convert state to string
  String toString() {
    Map<String, dynamic> state = new Map<String, dynamic>();
    state['jsontokenstate'] = this.jsontokenstate.toMap();
    state['group'] = this._group;
    state['file'] = this._file;
    state['start'] = this._start;
    state['end'] = this._end;
    state['delay'] = this._delay;
    state['combine'] = this._combine;
    state['chunksize'] = this._chunksize;
    state['parse'] = new List<Map<String, dynamic>>();
    this._parse.forEach((MapEntry<String, dynamic> v) {
      Map<String, dynamic> map = new Map<String, dynamic>();
      map[v.key] = v.value;
      state['parse'].add(map);
    });
    return jsonEncode(state);
  }

  //Convert map to state
  AbstractStateReader.fromMap(Map<String, dynamic> content) {
    this.jsontokenstate =
        new JsonTokenState.empty().fromMap(content['jsontokenstate']);
    this._group = content['group'];
    this._file = content['file'];
    this._start = content['start'];
    this._end = content['end'];
    this._delay = content['delay'];
    this._combine = content['combine'];
    this._chunksize = content['chunksize'];
    content['parse'].forEach((dynamic value) {
      String key = value.keys.first.toString();
      if (value.values.first.runtimeType.toString().contains("Map")) {
        HashMap<String, dynamic> data = new HashMap<String, dynamic>();
        value.values.first.forEach((dynamic vkey, dynamic vv) {
          data[vkey.toString()] = vv;
        });
        parse.add(new MapEntry(key, data));
      } else {
        this._parse.add(new MapEntry(
            key,
            value.values.runtimeType.toString().contains('int')
                ? value.values.first.toString()
                : value.values.first));
      }
    });
  }
  //Convert string to state
  AbstractStateReader.fromString(String content) {
    Map<String, dynamic> state = jsonDecode(content);
    this.jsontokenstate =
        new JsonTokenState.empty().fromMap(state['jsontokenstate']);
    this._group = state['group'];
    this._file = state['file'];
    this._start = state['start'];
    this._end = state['end'];
    this._delay = state['delay'];
    this._combine = state['combine'];
    this._chunksize = state['chunksize'];
    this._parse = new List<MapEntry<String, dynamic>>();
    state['parse'].forEach((dynamic value) {
      String key = value.keys.first.toString();
      if (value.values.first.runtimeType.toString().contains("Map")) {
        HashMap<String, dynamic> data = new HashMap<String, dynamic>();
        value.values.first.forEach((dynamic vkey, dynamic vv) {
          data[vkey.toString()] = vv;
        });
        parse.add(new MapEntry(key, data));
      } else {
        this._parse.add(new MapEntry(
            key,
            value.values.runtimeType.toString().contains('int')
                ? value.values.first.toString()
                : value.values.first));
      }
    });
  }

  int get group {
    return this._group;
  }

  String get file {
    return this._file;
  }

  int get start {
    return this._start;
  }

  int get end {
    return this._end;
  }

  int get delay {
    return this._delay;
  }

  int get combine {
    return this._combine;
  }

  int get chunksize {
    return this._chunksize;
  }

  bool get isRemote {
    return this._file.startsWith('{');
  }

  List<MapEntry<String, dynamic>> get parse {
    return this._parse;
  }
}
